@@ -16,10 +16,10 @@
 
 import io
 import mimetypes
+import os
 
 from lxml import etree
 
-
 mimetype_initialised = False
 
 
@@ -33,9 +33,9 @@ def debug(obj):
 def parse_string(s):
     parser = etree.XMLParser(recover=True, resolve_entities=False)
     try:
-        tree = etree.parse(io.BytesIO(s.encode('utf-8')) , parser=parser)
-    except:
-        tree = etree.parse(io.BytesIO(s) , parser=parser)
+        tree = etree.parse(io.BytesIO(s.encode("utf-8")), parser=parser)
+    except Exception:
+        tree = etree.parse(io.BytesIO(s), parser=parser)
 
     return tree
 
@@ -43,7 +43,7 @@ def parse_string(s):
 def parse_html_string(s):
     from lxml import html
 
-    utf8_parser = html.HTMLParser(encoding='utf-8')
+    utf8_parser = html.HTMLParser(encoding="utf-8")
 
     html_tree = html.document_fromstring(s, parser=utf8_parser)
 
@@ -55,7 +55,7 @@ def guess_type(extenstion):
 
     if not mimetype_initialised:
         mimetypes.init()
-        mimetypes.add_type('application/xhtml+xml', '.xhtml')
+        mimetypes.add_type("application/xhtml+xml", ".xhtml")
         mimetype_initialised = True
 
     return mimetypes.guess_type(extenstion)
@@ -65,25 +65,25 @@ def create_pagebreak(pageref, label=None, html=True):
     from ebooklib.epub import NAMESPACES
 
     pageref_attributes = {
-        '{%s}type' % NAMESPACES['EPUB']: 'pagebreak',
-        'title': u'{}'.format(pageref),
-        'id': u'{}'.format(pageref),
-     }
+        "{%s}type" % NAMESPACES["EPUB"]: "pagebreak",  # noqa
+        "title": "{pageref}".format(pageref=pageref),  # noqa: UP032
+        "id": "{pageref}".format(pageref=pageref),  # noqa: UP032
+    }
 
-    pageref_elem = etree.Element('span', pageref_attributes, nsmap={'epub': NAMESPACES['EPUB']})
+    pageref_elem = etree.Element("span", pageref_attributes, nsmap={"epub": NAMESPACES["EPUB"]})
 
     if label:
         pageref_elem.text = label
 
     if html:
-        return etree.tostring(pageref_elem, encoding='unicode')
+        return etree.tostring(pageref_elem, encoding="unicode")
 
     return pageref_elem
 
 
 def get_headers(elem):
     for n in range(1, 7):
-        headers = elem.xpath('./h{}'.format(n))
+        headers = elem.xpath("./h{n}".format(n=n))  # noqa: UP032
 
         if len(headers) > 0:
             text = headers[0].text_content().strip()
@@ -97,20 +97,20 @@ def get_pages(item):
     pages = []
 
     for elem in body.iter():
-        if 'epub:type' in elem.attrib:
-            if elem.get('id') is not None:
+        if "epub:type" in elem.attrib:
+            if elem.get("id") is not None:
                 _text = None
-                
-                if elem.text is not None and elem.text.strip() != '':
+
+                if elem.text is not None and elem.text.strip() != "":
                     _text = elem.text.strip()
 
                 if _text is None:
-                    _text = elem.get('aria-label')
+                    _text = elem.get("aria-label")
 
                 if _text is None:
                     _text = get_headers(elem)
 
-                pages.append((item.get_name(), elem.get('id'), _text or elem.get('id')))
+                pages.append((item.get_name(), elem.get("id"), _text or elem.get("id")))
 
     return pages
 
@@ -119,3 +119,15 @@ def get_pages_for_items(items):
     pages_from_docs = [get_pages(item) for item in items]
 
     return [item for pages in pages_from_docs for item in pages]
+
+
+class Directory(object):  # noqa: UP004
+    def __init__(self, directory_path):
+        self.directory_path = directory_path
+
+    def read(self, subname):
+        with open(os.path.join(self.directory_path, subname), "rb") as fp:
+            return fp.read()
+
+    def close(self):
+        pass
